package com.mokabyte.javaxml.jdom;

import java.io.*;
import org.jdom.*;
import org.jdom.output.*;

/**
 *  Creazione di un documento mediante la API di JDOM.
 *
 *  @author     Andrea Giovannini
 *  @version    1.0
 */
public class JDOMCreation {
    
	public static void main(String[] args) {
		Element root = new Element("todolist"), item;
		Document doc = new Document(root);

        item = buildItem("1", "6", "Leggere la posta", "2");
        root.addContent(item);
        
        item = buildItem("2", "9", "Riunione", "2");
        root.addContent(item);
        
        item = buildItem("3", "8", "Andare a correre nel parco", "1");
        root.addContent(item);
        
        try {
            // serializzazione su standard output
            XMLOutputter outputter = new XMLOutputter();
            outputter.setNewlines(true);
            outputter.setIndent("  ");
            outputter.output(doc, System.out);
        } catch(IOException e) {
            System.err.println("Errore durante la serializzazione del documento");
            e.printStackTrace();
        }
	}
        
    /**
     *  Costruzione di un elemento della todolist popolato
     *  con i dati dell'attivit.
     *
     *  @param  number      <code>String</code>     indice dell'attivit (PK)
     *  @param  priority    <code>String</code>     priorit
     *  @param  description <code>String</code>     descrizione
     *  @param  stato       <code>String</code>     stato di avanzamento dell'attivit
     *  @return <code>Element</code>    elemento JDOM contenente le informazioni dell'attivit.
     */
    private final static Element buildItem(String number, 
                                           String priority, 
                                           String description, 
                                           String state) {
		Element item = new Element("item"),
				numberEl = new Element("number"),
				priorityEl = new Element("priority"),
				descriptionEl = new Element("description"),
				stateEl = new Element("state");
        
		numberEl.setText(number);
		priorityEl.setText(priority);
		descriptionEl.setText(description);
		stateEl.setText(state);
        
        item.addContent(numberEl);
        item.addContent(priorityEl);
        item.addContent(descriptionEl);
        item.addContent(stateEl);
        
        return item;
    }
}